<?php

//Publish2 function to download the JSON feed with either cURL or file_get_contents
function p2_download_url($feedlink) {
	
	if (function_exists('curl_init')) {	
		$ch = curl_init();
		$timeout = 8; // set to zero for no timeout
		curl_setopt ($ch, CURLOPT_URL, $feedlink);
		curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt ($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
		$data = curl_exec($ch);
		if (empty($data)) {
			$data = 'timeout'; // Record a timeout if no data was returned
		}
		curl_close($ch);
		return $data;
	} else if (function_exists('file_get_contents')) {
		$data = file_get_contents($feedlink);
		return $data;
	}
	
}

//Publish2 function to clean a URL that the user submits
function p2_clean_url($feedlink) {
	
	$feedlink = ltrim($feedlink);
	$feedlink = rtrim($feedlink);
	$testhttp = substr($feedlink, 0, 7);
	if ($testhttp != 'http://')
		$feedlink = 'http://' . $feedlink;
	$testwww = substr($feedlink, 7, 3);	
	$testslash = substr($feedlink, -1);
	$feedlink = rtrim($feedlink, '/');
	return $feedlink;
	
}

//Publish2 function that checks to see whether the URL provides a legit JSON feed or not
function p2_check_url($feedlink) {
	
	if ($feedlink == 'http://' || $feedlink == '') {
		return 'no_url';
	}
	
	$json_url = $feedlink . '.js';
	$json_url .= '?number_of_items=5';
	$contents = p2_download_url($json_url);
	$testcontents = substr($contents, 0, 1);
	if ($testcontents == '{') {
		return true;
	} else {
		return false;		
	}
	
}

//Publish2 function that checks to see whether the required libraries are installed
function p2_check_environment() {
	
	if (!function_exists('json_decode')) {
		$check_environment['json'] = false;
	} else {
		$check_environment['json'] = true;
	}
	
	if (!function_exists('file_get_contents')) {
		$check_environment['file_get_contents'] = false;
	} else {
		$check_environment['file_get_contents'] = true;
	}
	
	if (!function_exists('curl_init')) {
		$check_environment['curl'] = false;
	} else {
		$check_environment['curl'] = true;
	}
	return $check_environment;
	
}

// Gets the video ID from a URL
function p2_getvideoid($link) {
	
	// Test for a YouTube video ID
	if (preg_match("/http:\/\/www.youtube.com\/watch/", $link) == 1) {	
		$youtubeidstart = strpos($link, '=');
		$youtubeidstart += 1;
		$youtubeidend = strpos($link, '&');
		if ($youtubeidend === false) {
			$videoid = substr($link, $youtubeidstart);
		} else {
			$youtubeidend += 1;
			$idlength = $youtubeidend - $youtubeidstart;
			$videoid = substr($link, $youtubeidstart, $idlength);
		}
	}
	// Test for a Vimeo video ID
	else if (preg_match("/http:\/\/www.vimeo.com/", $link) == 1 || preg_match("/http:\/\/vimeo.com/", $link) == 1) {
		if (preg_match("/http:\/\/www.vimeo.com/", $link) == 1) {
			$videoid = str_ireplace('http://www.vimeo.com/', '', $link);
		} else if (preg_match("/http:\/\/vimeo.com/", $link) == 1) {
			$videoid = str_ireplace('http://vimeo.com/', '', $link);
		}
	}
	
	return $videoid;
}

//Publish2 function to display links from a P2 JSON feed based on a variety of settings
function publish2($feedlink = null, $link_count = null, $publication_name = null, $publication_date = null, $journalist_full_name = null, $description = null, $tags = null, $link_format = null, $settings_source = null, $display_list = null, $video_width = null, $quote = null) {
	
	global $post;
	$defaults = get_option('publish2_settings');
	
	// If the request isn't coming from the widget or the page functions, then use the default settings
	if ($settings_source != 'widget' && $settings_source != 'page') { $options = $defaults; }
	
	//Checks to see if there are set variables passed to the function. If so, set the variables we'll use to that value 
	if ($feedlink != null) { $options['feedlink'] = $feedlink; }
	if ($link_count != null) { $options['link_count'] = $link_count; }
	if ($publication_name != null) { $options['publication_name'] = $publication_name; }
	if ($publication_date != null) { $options['publication_date'] = $publication_date; }
	if ($journalist_full_name != null) { $options['journalist_full_name'] = $journalist_full_name; }
	if ($description != null) { $options['description'] = $description; }
	if ($quote != null) { $options['quote'] = $quote; }
	if ($tags != null) { $options['tags'] = $tags; }
	if ($link_format != null) { $options['link_format'] = $link_format; }
	if ($display_list != null) { $options['display_list'] = $display_list; }
	if ($video_width != null) { $options['video_width'] = $video_width; }
	
	// If it's coming from the function and embed_video is set to false, then we go for zero width
	if ($settings_source != 'widget' && $settings_source != 'page') {
		if ($options['embed_video'] != true && $options['link_format'] == null) {
			$options['video_width'] = 0;
		}
	}
	$video_width = $options['video_width'];

	// Make sure the URL fits a certain standard so that we can build on it and add tricky things
	$options['feedlink'] = p2_clean_url($options['feedlink']);
	
	// Easter Egg: Make the widget contextual based on which page is loaded.
	// Set any of these to true to make your links contextual on that location.
	// Should degrade gracefully if it doesn't generate a legit feed.
	// Will be supported in coming version of the plugin.
	$dynamic_category = false;
	$dynamic_tag = false;
	$dynamic_author = false;
		
	// If it's a specific page, make the links dynamic to that page
	if (is_category() && $dynamic_category == true) {
		$cat_title = single_cat_title("", false);
		$cat_title = strtolower($cat_title);
		$feedlink_addition = str_replace(' ', '-', $cat_title);
		$json_url = $options['feedlink'] . '/' . $feedlink_addition . '.js';
	} else if (is_tag() && $dynamic_tag == true) {
		$tag_title = single_tag_title("", false);
		$tag_title = strtolower($tag_title);
		$feedlink_addition = str_replace(' ', '-', $tag_title);
		$json_url = $options['feedlink'] . '/' . $feedlink_addition . '.js';
	} else if (is_author() && $dynamic_author == true) {
		$user_id = get_the_author_ID();
		$feedlink = get_usermeta($user_id, 'publish2_url');
		$json_url = $feedlink . 'json';
	} else {
		$json_url = $options['feedlink'] . '.js';
	}
	
	$error_msg = '<p>It looks as though you may have entered the wrong URL during the setup process, or Publish2 is temporarily unresponsive. If you have questions, please contact <a href="mailto:support@publish2.com">support@publish2.com</a>. Thanks!</p>';

	// Finish creating the URL and download the contents of it
	$json_url .= '?number_of_items=' . $options['link_count'];
	$contents = p2_download_url($json_url);
	
	// Tests to make sure it's a valid JSON string; if not, replace with original URL (w/o any tags)
	$testcontents = substr($contents, 0, 1);
	if ($testcontents == '{') {
		$json_data = json_decode($contents, true);
	} else if ($contents == 'timeout') {
		if ($settings_source == 'page' || $settings_source == 'filter') {
			return $error_msg;
		} else {
			echo $error_msg;
			return;
		}
	} else {
		$json_url = $options['feedlink'] . '.js';
		$json_url .= '?number_of_items=' . $options['link_count'];
		$contents = p2_download_url($json_url);
		$testcontents = substr($contents, 0, 1);
		
		//Check to make sure it's legit data one last time. If not, then display an error message
		if ($testcontents != '{') {
			if ($settings_source == 'page' || $settings_source == 'filter') {
				return $error_msg;
			} else {
				echo $error_msg;
				return;
			}
		} else {
			$json_data = json_decode($contents, true);
		}
	}
	
	//If someone has indicated the order of the links with tokens, then use this option by default
	if ($options['link_format'] != "" && $options['link_format'] != null) {
		
		if ($display_list == true) { $links .= '<ul>'; }
		
		foreach ($json_data['items'] as $item) {
			
			$link_format = "";
			$link_format .= $options['link_format'];
			if ($display_list == true) { $link_format .= '<li>'; }
			
			if (preg_match("/http(?:s*):\/\/twitter.com\/(\S+)\/(?:status|statuses)\/(\d+)/", $item['link']) == 1) {
				if (stripos($link_format, '%headline%') != false) {
					$link_format = str_replace('%headline%', '<a href="'.$item['link'].'">'.$item['publication_name'].'</a>: '. $item['title'], $link_format);
					$link_format = str_replace('%source%', 'Twitter', $link_format);
				}
			}
			//Tests to see whether the tokens are included in the string. If so, then it changes them
			if (stripos($link_format, '%headline%') != false) {
				$link_format = str_replace('%headline%', '<a href="' . $item['link'] . '">' . $item['title'] . '</a>', $link_format);
			}
			if (stripos($link_format, '%video%') != false && preg_match("/http:\/\/www.youtube.com\/watch/", $item['link']) == 1) {
				$youtubeid = p2_getvideoid($item['link']);
				$video_height = .80208333333 * $video_width;
				$video_string = '<object width="' . $video_width . '" height="' . $video_height . '"><param name="movie" value="http://www.youtube.com/v/' . $youtubeid . '&hl=en&fs=1&"></param><param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param><embed src="http://www.youtube.com/v/' . $youtubeid . '&hl=en&fs=1&" type="application/x-shockwave-flash" allowscriptaccess="always" allowfullscreen="true" width="' . $video_width . '" height="' . $video_height . '"></embed></object>';
				$link_format = str_replace('%video%', $video_string, $link_format);
				
			} else if (stripos($link_format, '%video%') != false && (preg_match("/http:\/\/www.vimeo.com/", $item['link']) == 1 || preg_match("/http:\/\/vimeo.com/", $item['link']) == 1)) {
				
				$vimeoid = p2_getvideoid($item['link']);
				$video_height = .675 * $video_width;
				$video_string = '<object width="' . $video_width . '" height="' . $video_height . '"><param name="allowfullscreen" value="true" /><param name="allowscriptaccess" value="always" /><param name="movie" value="http://vimeo.com/moogaloop.swf?clip_id=' . $vimeoid . '&amp;server=vimeo.com&amp;show_title=0&amp;show_byline=0&amp;show_portrait=0&amp;color=00adef&amp;fullscreen=1" /><embed src="http://vimeo.com/moogaloop.swf?clip_id=' . $vimeoid . '&amp;server=vimeo.com&amp;show_title=0&amp;show_byline=0&amp;show_portrait=0&amp;color=00adef&amp;fullscreen=1" type="application/x-shockwave-flash" allowfullscreen="true" allowscriptaccess="always" width="' . $video_width . '" height="' . $video_height . '"></embed></object>';
				$link_format = str_replace('%video%', $video_string, $link_format);
				
			} else if (stripos($link_format, '%video%') != false) {
				$link_format = str_replace('%video%', '', $link_format);
			}
			if (stripos($link_format, '%source%') != false) {
				$link_format = str_replace('%source%', $item['publication_name'], $link_format);
			}
			if (stripos($link_format, '%date%') != false) {
				$link_format = str_replace('%date%', $item['publication_date'], $link_format);
			}
			if (stripos($link_format, '%journalist%') != false) {
				$link_format = str_replace('%journalist%', '<a href="'.$item['journalist_profile'].'">'.$item['journalist_full_name'].'</a>', $link_format);
			}
			if (stripos($link_format, '%comment%') != false) {
				$link_format = str_replace('%comment%', $item['description'], $link_format);
			}
			if (stripos($link_format, '%quote%') != false) {
				$link_format = str_replace('%quote%', $item['quote'], $link_format);
			}
			if (stripos($link_format, '%tags%') != false && is_array($item['tags'])) {
				$tag_list = ''; //dislaying tags 
				foreach ($item['tags'][0] as $tag) {
					$tag_list .= '<a href="'. $tag['link'] . '" class="publish2_link"';
					$tag_list .= '>' . $tag['name'] . '</a>' . ", ";
				}
				$tag_list = rtrim($tag_list, ', ');
				$link_format = str_replace('%tags%', $tag_list, $link_format);
			}

			$links .= $link_format;
			if ($display_list == true) { $links .= '</li>'; }
				
		}
		
		if ($display_list == true) { $links .= '</ul>'; }
		
	} else if (($settings_source == 'widget' && $options['link_format'] == "") || $display_list == true) {
		
		$links .= '<ul>';
		
		foreach ($json_data['items'] as $item) {
			$links .= '<li>';
			
			// Check to see whether what was saved was a tweet. If so, display differently
			if (preg_match("/http(?:s*):\/\/twitter.com\/(\S+)\/(?:status|statuses)\/(\d+)/", $item['link']) == 1) {
				$links .= '<span class="publish2_tweet">';
				if (strlen($item['publication_name']) != 0) {
					$links .= '<a href="'. $item['link'] . '">' . $item['publication_name'] . '</a>: ';
				}
				$links .= $item['title'] . '</span>';
				if ($options['publication_name'] == true && ($options['publication_date'] == true && strlen($item['publication_date']) != 0)) {
					$links .= '<div><span class="publish2_story_publication_name">Twitter</span> | <span class="publish2_story_publication_date">' . $item['publication_date'] . '</span></div>';
				} else if ($options['publication_name'] == false && ($options['publication_date'] == true && strlen($item['publication_date']) != 0)) {
					$links .= '<div><span class="publish2_story_publication_date">' . $item['publication_date'] . '</span></div>';
				} else if ($options['publication_name'] == true && $options['publication_date'] == false) {
					$links .= '<div><span class="publish2_story_publication_name">Twitter</span></div>';
				}
			} else {
			
				$links .= '<a href="'. $item['link'] . '" class="publish2_story_headline">' . $item['title'] . '</a>';
				
				if ($video_width != 0 && preg_match("/http:\/\/www.youtube.com\/watch/", $item['link']) == 1) {

					// Find the YouTube ID for the video
					$youtubeid = p2_getvideoid($item['link']);
					
					// Set the video height based on a proprietary algorithm
					$video_height = .80208333333 * $video_width;
					
					$links .= '<div class="publish2_video_embed"><object width="' . $video_width . '" height="' . $video_height . '"><param name="movie" value="http://www.youtube.com/v/' . $youtubeid . '&hl=en&fs=1&"></param><param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param><embed src="http://www.youtube.com/v/' . $youtubeid . '&hl=en&fs=1&" type="application/x-shockwave-flash" allowscriptaccess="always" allowfullscreen="true" width="' . $video_width . '" height="' . $video_height . '"></embed></object></div>';

				} else if ($video_width != 0 && (preg_match("/http:\/\/www.vimeo.com/", $item['link']) == 1 || preg_match("/http:\/\/vimeo.com/", $item['link']) == 1)) {
					
					$vimeoid = p2_getvideoid($item['link']);
					$video_height = .675 * $video_width;
					
					$links .= '<div class="publish2_video_embed"><object width="' . $video_width . '" height="' . $video_height . '"><param name="allowfullscreen" value="true" /><param name="allowscriptaccess" value="always" /><param name="movie" value="http://vimeo.com/moogaloop.swf?clip_id=' . $vimeoid . '&amp;server=vimeo.com&amp;show_title=0&amp;show_byline=0&amp;show_portrait=0&amp;color=00adef&amp;fullscreen=1" /><embed src="http://vimeo.com/moogaloop.swf?clip_id=' . $vimeoid . '&amp;server=vimeo.com&amp;show_title=0&amp;show_byline=0&amp;show_portrait=0&amp;color=00adef&amp;fullscreen=1" type="application/x-shockwave-flash" allowfullscreen="true" allowscriptaccess="always" width="' . $video_width . '" height="' . $video_height . '"></embed></object></div>';
					
				}

				//whether to show the pub name, date, both or none. Includes a filter if the user didn't save publication_name or publication_date
				if (($options['publication_name'] == true && strlen($item['publication_name']) != 0) && ($options['publication_date'] == true && strlen($item['publication_date']) != 0)) {
					$links .= '<div>' . '<span class="publish2_story_publication_name">' . $item['publication_name'] . '</span>' . ' | ' . '<span class="publish2_story_publication_date">' . $item['publication_date'] . '</span>' . '</div>';
				} else if (($options['publication_name'] == true && strlen($item['publication_name']) != 0) && ($options['publication_date'] == true && strlen($item['publication_date']) == 0)) {
					$links .= '<div>' . '<span class="publish2_story_publication_name">' . $item['publication_name'] . '</span>' . '</div>';
				} else if (($options['publication_name'] == true && strlen($item['publication_name']) == 0) && ($options['publication_date'] == true && strlen($item['publication_date']) != 0)) {
					$links .= '<div>' . '<span class="publish2_story_publication_date">' . $item['publication_date'] . '</span>' . '</div>';
				} else if (($options['publication_name'] == true && strlen($item['publication_name']) != 0) && ($options['publication_date'] == false)) {
					$links .= '<div>' . '<span class="publish2_story_publication_name">' . $item['publication_name'] . '</span>' . '</div>';
				} else if (($options['publication_date'] == true && strlen($item['publication_date']) != 0) && ($options['publication_name'] == false)) {
					$links .= '<div>' . '<span class="publish2_story_publication_date">' . $item['publication_date'] . '</span>' . '</div>';
				}
			
			}

			//whether to show comments or not. Includes to drop the whole graf if there isn't a comment
			if (($options['description'] == true && strlen($item['description']) != 0) && $options['journalist_full_name'] == true) {
				$links .= '<div>' . '<a href="'. $item['journalist_profile'] . '" class="publish2_journalist_profile">' . $item['journalist_full_name'] . '</a>' . ' says: ';
				$links .= '<span class="publish2_story_description">' . $item['description'] . '</span>' . '</div>';
			}
			else if ($options['description'] == true) {
				$links .= '<div>' . '<span class="publish2_story_description">' . $item['description'] . '</span>' . '</div>';
			}
			
			if ($options['quote'] == true && strlen($item['quote']) != 0) {
				$links .= '<div><span class="publish2_story_quote"><span class="publish2_story_quote_slug">Quote:</span> ' . $item['quote'] . '</span></div>';
			}

			//option whether to display the tags or not
			if ($options['tags'] == true && is_array($item['tags'])) {
				$links .= '<div>' . 'Tags: ';
				$tag_list = ''; //dislaying tags 
				foreach ($item['tags'][0] as $tag) {
					$tag_list .= '<a href="'. $tag['link'] . '" class="publish2_story_tags">' . $tag['name'] . '</a>' . ", ";
				}
				$tag_list = rtrim($tag_list, ', ');
				$links .= $tag_list;
				$links .= '</div>';		
			}
			$links .= '</li>';
		}
		$links .= '</ul>';

	} else {
		
		if ($display_list == true) { $links .= '<ul>'; }

		foreach ($json_data['items'] as $item) {

			if ($display_list == true) { $links .= '<li>'; }
				
			// Check to see whether what was saved was a tweet. If so, display the publication name alongside the title
			if (preg_match("/http(?:s*):\/\/twitter.com\/(\S+)\/(?:status|statuses)\/(\d+)/", $item['link']) == 1) {
				if ($settings_source == 'page') { $links .= '<h3>'; } else { $links .= '<h4>'; }
				$links .= '<span class="publish2_tweet">';
				if (strlen($item['publication_name']) != 0) {
					$links .= '<a href="'. $item['link'] . '">' . $item['publication_name'] . '</a>: ';
				}
				$links .= $item['title'];
				$links .= '</span>';
				if ($settings_source == 'page') { $links .= '</h3>'; } else { $links .= '</h4>'; }
				if ($options['publication_name'] == true && ($options['publication_date'] == true && strlen($item['publication_date']) != 0)) {
					$links .= '<p><span class="publish2_story_publication_name">Twitter</span> | <span class="publish2_story_publication_date">' . $item['publication_date'] . '</span></p>';
				} else if ($options['publication_name'] == false && ($options['publication_date'] == true && strlen($item['publication_date']) != 0)) {
					$links .= '<p><span class="publish2_story_publication_date">' . $item['publication_date'] . '</span></p>';
				} else if ($options['publication_name'] == true && $options['publication_date'] == false) {
					$links .= '<p><span class="publish2_story_publication_name">Twitter</span></p>';
				}
			} else {

				if ($settings_source == 'page') { $links .= '<h3>'; } else { $links .= '<h4>'; }
				$links .= '<a href="'. $item['link'] . '" class="publish2_story_headline">' . $item['title'] . '</a>';
				if ($settings_source == 'page') { $links .= '</h3>'; } else { $links .= '</h4>'; }
				
				if ($video_width != 0 && preg_match("/http:\/\/www.youtube.com\/watch/", $item['link']) == 1) {

					// Find the YouTube ID for the video
					$youtubeid = p2_getvideoid($item['link']);
					
					// Set the video height based on a proprietary algorithm
					$video_height = .80208333333 * $video_width;
					
					$links .= '<p class="publish2_video_embed"><object width="' . $video_width . '" height="' . $video_height . '"><param name="movie" value="http://www.youtube.com/v/' . $youtubeid . '&hl=en&fs=1&"></param><param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param><embed src="http://www.youtube.com/v/' . $youtubeid . '&hl=en&fs=1&" type="application/x-shockwave-flash" allowscriptaccess="always" allowfullscreen="true" width="' . $video_width . '" height="' . $video_height . '"></embed></object></p>';

				} else if ($video_width != 0 && (preg_match("/http:\/\/www.vimeo.com/", $item['link']) == 1 || preg_match("/http:\/\/vimeo.com/", $item['link']) == 1)) {

					$vimeoid = p2_getvideoid($item['link']);
					$video_height = .675 * $video_width;

					$links .= '<p class="publish2_video_embed"><object width="' . $video_width . '" height="' . $video_height . '"><param name="allowfullscreen" value="true" /><param name="allowscriptaccess" value="always" /><param name="movie" value="http://vimeo.com/moogaloop.swf?clip_id=' . $vimeoid . '&amp;server=vimeo.com&amp;show_title=0&amp;show_byline=0&amp;show_portrait=0&amp;color=00adef&amp;fullscreen=1" /><embed src="http://vimeo.com/moogaloop.swf?clip_id=' . $vimeoid . '&amp;server=vimeo.com&amp;show_title=0&amp;show_byline=0&amp;show_portrait=0&amp;color=00adef&amp;fullscreen=1" type="application/x-shockwave-flash" allowfullscreen="true" allowscriptaccess="always" width="' . $video_width . '" height="' . $video_height . '"></embed></object></p>';

				}

				//whether to show the pub name, date, both or none. Includes a filter if the user didn't save publication_name or publication_date
				if (($options['publication_name'] == true && strlen($item['publication_name']) != 0) && ($options['publication_date'] == true && strlen($item['publication_date']) != 0)) {
					$links .= '<p>';
					$links .= '<span class="publish2_story_publication_name">' . $item['publication_name'] . '</span>' . ' | ' . '<span class="publish2_story_publication_date">' . $item['publication_date'] . '</span>';
					$links .= '</p>';
				} else if (($options['publication_name'] == true && strlen($item['publication_name']) != 0) && ($options['publication_date'] == true && strlen($item['publication_date']) == 0)) {
					$links .= '<p>';
					$links .= '<span class="publish2_story_publication_name">' . $item['publication_name'] . '</span>';
					$links .= '</p>';
				} else if (($options['publication_name'] == true && strlen($item['publication_name']) == 0) && ($options['publication_date'] == true && strlen($item['publication_date']) != 0)) {
					$links .= '<p>';
					$links .= '<span class="publish2_story_publication_date">' . $item['publication_date'] . '</span>';
					$links .= '</p>';
				} else if (($options['publication_name'] == true && strlen($item['publication_name']) != 0) && ($options['publication_date'] == false)) {
					$links .= '<p>';
					$links .= '<span class="publish2_story_publication_name">' . $item['publication_name'] . '</span>';
					$links .= '</p>';
				} else if (($options['publication_date'] == true && strlen($item['publication_date']) != 0) && ($options['publication_name'] == false)) {
					$links .= '<p>';
					$links .= '<span class="publish2_story_publication_date">' . $item['publication_date'] . '</span>';
					$links .= '</p>';
				}
			
			}

			//whether to show comments or not. Includes to drop the whole graf if there isn't a comment
			if (($options['description'] == true && strlen($item['description']) != 0) && $options['journalist_full_name'] == true) {
				$links .= '<p>';
				$links .= '<a href="'. $item['journalist_profile'] . '" class="publish2_journalist_profile">' . $item['journalist_full_name'] . '</a>' . ' says: ';
				$links .= '<span class="publish2_story_description">' . $item['description'] . '</span>';
				$links .= '</p>';
			} else if ($options['description'] == true && strlen($item['description']) != 0) {
				$links .= '<p>';
				$links .= '<span class="publish2_story_description">' . $item['description'] . '</span>';
				$links .= '</p>';
			}
			
			if ($options['quote'] == true && strlen($item['quote']) != 0) {
				$links .= '<p>';
				$links .= '<span class="publish2_story_quote"><span class="publish2_story_quote_slug">Quote:</span> ' . $item['quote'] . '</span>';
				$links .= '</p>';
			}

			//option whether to display the tags or not
			if ($options['tags'] == true && is_array($item['tags'])) {
				$links .= '<p>';
				$links .= 'Tags: ';
				$tag_list = ''; //dislaying tags 
				foreach ($item['tags'][0] as $tag) {
					$tag_list .= '<a href="'. $tag['link'] . '" class="publish2_story_tags">' . $tag['name'] . '</a>' . ", ";
				}
				$tag_list = rtrim($tag_list, ', ');
				$links .= $tag_list;
				$links .= '</p>';		
			}
			if ($display_list == true) { $links .= '</li>'; }

		}
		if ($display_list == true) { $links .= '</ul>'; }

	}
	
	if ($settings_source == 'page' || $settings_source == 'filter') {
		return $links;
	} else {
		echo $links;
	}
	
}

?>